library(UCell)
library(Seurat)
library(ggplot2)
library(dplyr)
library(tidyr)

### load signatures

vexas_50 <- read.gmt("/DATA/31/molteni/vexas_bm/reference/custom_vexas_50.gmt")

vexas_100 <- read.gmt("/DATA/31/molteni/vexas_bm/reference/custom_vexas_100.gmt")

vexas_signature <- list(vexas_50 = vexas_50[[2]],
                        vexas_100 = vexas_100[[2]])


# load dataset

query <- readRDS("/DATA/31/molteni/vexas_bm/results/integration/pc15/BM.combo_anno.rds")


### UCell


# compute modules

names(vexas_signature) <- paste0("VEXAS_Xenograft_sig", c("50", "100"))

ncol <- ncol(query@meta.data)

query <- AddModuleScore_UCell(query, features = vexas_signature)

colnames(query@meta.data) <- c(colnames(query@meta.data)[seq_len(ncol)], names(vexas_signature))


# wilcoxon test

x <- melt(data = query@meta.data, id.vars = c("condition", "celltypes_annot"), measure.vars = c("VEXAS_Xenograft_sig50"))

t_predpop <- x %>% dplyr::group_by(variable, celltypes_annot) %>% dplyr::summarise(pvalue = wilcox.test(x = value[condition == "PZ"], y = value[condition == "HD"])$p.value)

t_predpop$bonferroni_adjpvalue <- p.adjust(p = t_predpop$pvalue)

t_predpop <- t_predpop[order(t_predpop$bonferroni_adjpvalue, decreasing = F),]

write.table(x = t_predpop, file = "VexasXenograftSignatures_SeuratAnnotatedClustersWilcoxonTest_VEXASvsHD_sig50.txt", sep = "\t", row.names = F, col.names = T, quote = F)

# violin plots: VEXAS vs HD

t_predpop$sig_label <- ifelse(t_predpop$bonferroni_adjpvalue > 0.05, "ns",
                              
                              ifelse(t_predpop$bonferroni_adjpvalue < 0.05, "*",
                                     
                                     ifelse(t_predpop$bonferroni_adjpvalue < 0.01, "**",
                                            
                                            ifelse(t_predpop$bonferroni_adjpvalue < 0.001, "***", "***"))))


g <- query@meta.data %>%
  
  ggplot() +
  
  theme_classic() +
  
  geom_violin(aes(x = celltypes_annot, y = VEXAS_Xenograft_sig50, fill = condition), scale = "width") +
  
  geom_text(data = t_predpop, aes(x = celltypes_annot, y = 0.7, label = sig_label)) +
  
  theme(plot.title = element_text(hjust = 0.5, size = 10),
        
        axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1),
        
        legend.position = "right") +
  
  ylab("UCell Module score") + xlab("") +
  
  ggtitle("VEXAS xenograft signature (n = 50)") +
  
  theme(axis.text.x = element_text(angle = 45, , vjust = 1, hjust = 1)) +
  
  scale_fill_manual(values = adjustcolor(col = c("#F8766D", "#02818a"), alpha.f = 0.8), name = "")

ggsave(g,
       
       filename = "ViolinPlots_VexasXenograftSignatureTop50.pdf",
       
       width = length(unique(query$celltypes_annot))*5*0.1,
       
       height = 5,
       
       limitsize = FALSE)
  